@@ -5,9 +5,23 @@
 #
 # First you have to install the necessary tools:
 #
-# For Windows: MinGW/MSYS with development tools, Qt, xsltproc,
-# html\docbook.xsl. Set the environment variables MSYSDIR, XSLTPROCDIR,
-# DOCBOOKDIR to the install directories. They are used in win32/buildkit3.bat.
+# For Windows:
+#
+# Building the libraries needs msys/MinGW, CMake, yasm.
+# You should use the MinGW which comes with Qt and add msys tools to build
+# the libraries.
+# Download yasm from
+# http://www.tortall.net/projects/yasm/releases/yasm-1.2.0-win32.exe
+# and copy it into msys /bin as yasm.exe.
+# Start the msys shell, add cmake to the path and start this script.
+# When the script has run successfully, the libraries are installed below
+# /usr/local/ in msys. You can then proceed to the Kid3 build.
+#
+# Building Kid3 needs MinGW, CMake, Qt, xsltproc, html\docbook.xsl, dumpbin.
+# Dumpbin is needed for the final packages and can be found in the MS SDK or
+# MS Visual C++ Express Edition. Set the environment variables in
+# win32/buildkid3.bat, so that these tools can be found, then start
+# buildkid3.bat from a Windows command prompt.
 #
 # For Mac: XCode, Qt, html\docbook.xsl. XCode and Qt should be installed at
 # the default location, docbook.xsl in
@@ -18,24 +32,51 @@
 # it should still work.
 #
 # buildlibs.sh will download, build and install zlib, libogg, libvorbis,
-# flac, id3lib, taglib and mp4v2. You are then ready to build Kid3 from
-# the win32 or macosx directories by starting buildkid3.bat (Windows) or
-# buildkid3.sh (Mac). A binary package can be created using createpkg.bat,
-# or createpkg.sh respectively.
+# flac, id3lib, taglib, libav, chromaprint. You are then ready to build Kid3
+# from the win32 or macosx directories by starting buildkid3.bat (Windows) or
+# buildkid3.sh (Mac).
+
+thisdir=$(pwd)
 
 kernel=$(uname)
 test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
+# Uncomment for debug build
+#ENABLE_DEBUG=--enable-debug
+#CMAKE_BUILD_TYPE_DEBUG="-DCMAKE_BUILD_TYPE=Debug"
+
+if test $kernel = "MINGW"; then
+CMAKE_OPTIONS="-G \"MSYS Makefiles\" -DCMAKE_INSTALL_PREFIX=/usr/local"
+elif test $kernel = "Darwin"; then
+CMAKE_OPTIONS="-G \"Unix Makefiles\""
+fi
+
+fixcmakeinst() {
+  if test -d inst && test $kernel = "MINGW"; then
+    cd inst
+    if test -d prg; then
+      rm -rf usr
+      mv prg/msys usr
+      rmdir prg
+    elif test -d msys; then
+      rm -rf usr
+      mv msys/1.0 usr
+      rmdir msys
+    elif test -d MinGW; then
+      mv MinGW usr
+    fi
+    cd ..
+  fi
+}
+
+
 # Download sources
 
 test -d source || mkdir source
 cd source
 
-test -f mp4v2-1.9.1.tar.bz2 ||
-wget http://mp4v2.googlecode.com/files/mp4v2-1.9.1.tar.bz2
-
-test -f flac_1.2.1-3.diff.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1-3.diff.gz
+test -f flac_1.2.1-6.diff.gz ||
+wget http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1-6.diff.gz
 test -f flac_1.2.1.orig.tar.gz ||
 wget http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1.orig.tar.gz
 
@@ -54,15 +95,30 @@ wget http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2-1.
 test -f libvorbis_1.3.2.orig.tar.gz ||
 wget http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2.orig.tar.gz
 
-test -f taglib_1.7-1.debian.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.7-1.debian.tar.gz
-test -f taglib_1.7.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.7.orig.tar.gz
+#test -f taglib_1.7-1.debian.tar.gz ||
+#wget http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.7-1.debian.tar.gz
+test -f taglib-1.7.1.tar.gz ||
+wget http://developer.kde.org/~wheeler/files/src/taglib-1.7.1.tar.gz
 
-test -f zlib_1.2.5.dfsg-1.debian.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.5.dfsg-1.debian.tar.gz
-test -f zlib_1.2.5.dfsg.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.5.dfsg.orig.tar.gz
+test -f zlib_1.2.6.dfsg-2.debian.tar.gz ||
+wget http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.6.dfsg-2.debian.tar.gz
+test -f zlib_1.2.6.dfsg.orig.tar.gz ||
+wget http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.6.dfsg.orig.tar.gz
+
+test -f libav_0.8.1.orig.tar.gz ||
+wget http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.1.orig.tar.gz
+test -f libav_0.8.1-4.debian.tar.gz ||
+wget http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.1-4.debian.tar.gz
+
+test -f chromaprint_0.6.orig.tar.gz ||
+wget http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.6.orig.tar.gz
+test -f chromaprint_0.6-1.debian.tar.gz ||
+wget http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.6-1.debian.tar.gz
+
+#test -f mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2 ||
+#wget http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2
+#test -f mp4v2_1.9.1+svn479~dfsg0-3.debian.tar.gz ||
+#wget http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_1.9.1+svn479~dfsg0-3.debian.tar.gz
 
 # Create patch files
 
@@ -167,9 +223,18 @@ EOF
 test -f id3lib-3.8.3_mingw.patch ||
 cat >id3lib-3.8.3_mingw.patch <<"EOF"
 diff -ru id3lib-3.8.3.orig/configure.in id3lib-3.8.3/configure.in
---- id3lib-3.8.3.orig/configure.in	Sun Mar  2 00:23:00 2003
-+++ id3lib-3.8.3/configure.in	Thu Oct 11 08:55:26 2007
-@@ -249,10 +249,10 @@
+--- id3lib-3.8.3.orig/configure.in	2012-02-05 13:09:59 +0100
++++ id3lib-3.8.3/configure.in	2012-02-05 13:16:33 +0100
+@@ -222,7 +222,7 @@
+ AC_LANG_CPLUSPLUS
+ AC_CHECK_HEADERS(libcw/sys.h)
+ AC_CHECK_HEADERS(cctype climits cstdio cstdlib bitset cstring)
+-AC_CHECK_HEADERS(fstream iostream iomanip vector \
++AC_CHECK_HEADERS(fstream iostream vector \
+ 	,,AC_MSG_ERROR([Missing a vital header file for id3lib - download them here: http://gcc.gnu.org/libstdc++/ or better - compile a newer compiler like gcc3.x])
+ )
+ AC_CHECK_HEADERS(               \
+@@ -248,10 +248,10 @@
  AM_CONDITIONAL(ID3_NEEDGETOPT_LONG, test x$ac_cv_func_getopt_long = xno)
  
  AC_CHECK_FUNCS(mkstemp)
@@ -184,10 +249,9 @@ diff -ru id3lib-3.8.3.orig/configure.in id3lib-3.8.3/configure.in
  
  dnl Checks for typedefs, structures, and compiler characteristics.
  AC_TYPE_SIZE_T
-Only in id3lib-3.8.3: configure.in~
 diff -ru id3lib-3.8.3.orig/include/id3/globals.h id3lib-3.8.3/include/id3/globals.h
---- id3lib-3.8.3.orig/include/id3/globals.h	Sun Mar  2 00:23:00 2003
-+++ id3lib-3.8.3/include/id3/globals.h	Thu Oct 11 08:56:28 2007
+--- id3lib-3.8.3.orig/include/id3/globals.h	2012-02-05 13:09:59 +0100
++++ id3lib-3.8.3/include/id3/globals.h	2012-02-05 13:15:42 +0100
 @@ -41,7 +41,7 @@
   * we prefix variable declarations so they can
   * properly get exported in windows dlls.
@@ -432,6 +496,53 @@ index 3e6d667..d0ff728 100644
          TagLib::ByteVector renderCovr(const ByteVector &name, Item &item);
 EOF
 
+test -f taglib-itunes-id3v22.patch ||
+cat >taglib-itunes-id3v22.patch <<"EOF"
+diff --git a/taglib/mpeg/id3v2/id3v2framefactory.cpp b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+index 40e454e..b6bc34a 100644
+--- a/taglib/mpeg/id3v2/id3v2framefactory.cpp
++++ b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+@@ -310,6 +310,7 @@ bool FrameFactory::updateFrame(Frame::Header *header) const
+     convertFrame("TBP", "TBPM", header);
+     convertFrame("TCM", "TCOM", header);
+     convertFrame("TCO", "TCON", header);
++    convertFrame("TCP", "TCMP", header);
+     convertFrame("TCR", "TCOP", header);
+     convertFrame("TDY", "TDLY", header);
+     convertFrame("TEN", "TENC", header);
+@@ -332,7 +333,12 @@ bool FrameFactory::updateFrame(Frame::Header *header) const
+     convertFrame("TRC", "TSRC", header);
+     convertFrame("TRD", "TDRC", header);
+     convertFrame("TRK", "TRCK", header);
++    convertFrame("TS2", "TSO2", header);
++    convertFrame("TSA", "TSOA", header);
++    convertFrame("TSC", "TSOC", header);
++    convertFrame("TSP", "TSOP", header);
+     convertFrame("TSS", "TSSE", header);
++    convertFrame("TST", "TSOT", header);
+     convertFrame("TT1", "TIT1", header);
+     convertFrame("TT2", "TIT2", header);
+     convertFrame("TT3", "TIT3", header);
+EOF
+
+test -f libav_sws.patch ||
+cat >libav_sws.patch <<"EOF"
+--- cmdutils.c.org      2011-09-17 13:36:43.000000000 -0700
++++ cmdutils.c  2011-09-17 15:54:37.453134577 -0700
+@@ -311,6 +311,11 @@
+     const AVOption *oc, *of, *os;
+     char opt_stripped[128];
+     const char *p;
++// SPage: avoid sws_get_class failure
++#if !CONFIG_SWSCALE
++#   define sws_get_class(x)  0
++#endif
++
+     const AVClass *cc = avcodec_get_class(), *fc = avformat_get_class(), *sc = sws_get_class();
+ 
+     if (!(p = strchr(opt, ':')))
+EOF
+
 cd ..
 
 
@@ -439,10 +550,10 @@ cd ..
 
 # zlib
 
-if ! test -d zlib-1.2.5.dfsg; then
-tar xzf source/zlib_1.2.5.dfsg.orig.tar.gz
-cd zlib-1.2.5.dfsg/
-tar xzf ../source/zlib_1.2.5.dfsg-1.debian.tar.gz
+if ! test -d zlib-1.2.6.dfsg; then
+tar xzf source/zlib_1.2.6.dfsg.orig.tar.gz
+cd zlib-1.2.6.dfsg/
+tar xzf ../source/zlib_1.2.6.dfsg-2.debian.tar.gz
 for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 cd ..
 fi
@@ -470,8 +581,8 @@ fi
 if ! test -d flac-1.2.1; then
 tar xzf source/flac_1.2.1.orig.tar.gz
 cd flac-1.2.1/
-gunzip -c ../source/flac_1.2.1-3.diff.gz | patch -p1
-for f in debian/patches/*.dpatch; do patch -p1 <$f; done
+gunzip -c ../source/flac_1.2.1-6.diff.gz | patch -p1
+for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 patch -p1 <../source/flac_1.2.1_size_t_max_patch.diff
 if test $kernel = "Darwin"; then
 patch -p1 <../source/fink_flac.patch
@@ -494,42 +605,56 @@ fi
 
 # taglib
 
-if ! test -d taglib-1.7; then
-tar xzf source/taglib_1.7.orig.tar.gz
-cd taglib-1.7/
-tar xzf ../source/taglib_1.7-1.debian.tar.gz
-for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+if ! test -d taglib-1.7.1; then
+tar xzf source/taglib-1.7.1.tar.gz
+cd taglib-1.7.1/
+#tar xzf ../source/taglib_1.7-1.debian.tar.gz
+#for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 patch -p1 <../source/taglib-mp4-uinttypes.patch
+patch -p1 <../source/taglib-itunes-id3v22.patch
+cd ..
+fi
+
+# libav
+
+if ! test -d libav-0.8.1; then
+tar xzf source/libav_0.8.1.orig.tar.gz
+cd libav-0.8.1/
+tar xzf ../source/libav_0.8.1-4.debian.tar.gz
+for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+patch -p0 <../source/libav_sws.patch
+cd ..
+fi
+
+# chromaprint
+
+if ! test -d chromaprint-0.6; then
+tar xzf source/chromaprint_0.6.orig.tar.gz
+cd chromaprint-0.6/
+tar xzf ../source/chromaprint_0.6-1.debian.tar.gz
 cd ..
 fi
 
 # mp4v2
 
-if ! test -d mp4v2-1.9.1; then
-tar xjf source/mp4v2-1.9.1.tar.bz2
-fi
+#if ! test -d mp4v2-1.9.1+svn479~dfsg0; then
+#tar xjf source/mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2
+#cd mp4v2-1.9.1+svn479~dfsg0/
+#tar xzf ../source/mp4v2_1.9.1+svn479~dfsg0-3.debian.tar.gz
+#cd ..
+#fi
 
 
 # Build from sources
 
-# Uncomment for debug build
-#ENABLE_DEBUG=--enable-debug
-#CMAKE_BUILD_TYPE_DEBUG="-DCMAKE_BUILD_TYPE=Debug"
-
-if test $kernel = "MINGW"; then
-CMAKE_OPTIONS="-G \"MSYS Makefiles\" -DCMAKE_INSTALL_PREFIX=/usr/local"
-elif test $kernel = "Darwin"; then
-CMAKE_OPTIONS="-G \"Unix Makefiles\""
-fi
-
 test -d bin || mkdir bin
 
 # zlib
 
-cd zlib-1.2.5.dfsg/
+cd zlib-1.2.6.dfsg/
 if test $kernel = "MINGW"; then
 make -f win32/Makefile.gcc
-make install -f win32/Makefile.gcc INCLUDE_PATH=`pwd`/inst/usr/local/include LIBRARY_PATH=`pwd`/inst/usr/local/lib
+make install -f win32/Makefile.gcc INCLUDE_PATH=`pwd`/inst/usr/local/include LIBRARY_PATH=`pwd`/inst/usr/local/lib BINARY_PATH=`pwd`/inst/usr/local/bin
 else
 CFLAGS="-O3 -Wall -DNO_FSEEKO" ./configure --static
 sed 's/LIBS=$(STATICLIB) $(SHAREDLIB) $(SHAREDLIBV)/LIBS=$(STATICLIB)/' Makefile >Makefile.inst
@@ -537,7 +662,7 @@ mkdir -p inst/usr/local
 make install -f Makefile.inst prefix=`pwd`/inst/usr/local
 fi
 cd inst
-tar czf ../../bin/zlib-1.2.5.tgz usr
+tar czf ../../bin/zlib-1.2.6.tgz usr
 cd ../..
 
 # libogg
@@ -554,7 +679,7 @@ cd ../..
 # libvorbis
 
 cd libvorbis-1.3.2/
-test -f Makefile || ./configure --enable-shared=no --enable-static=yes --with-ogg=/usr/local $ENABLE_DEBUG
+test -f Makefile || ./configure --enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.2.2~dfsg/inst/usr/local $ENABLE_DEBUG
 make
 mkdir inst
 make install DESTDIR=`pwd`/inst
@@ -565,7 +690,7 @@ cd ../..
 # libflac
 
 cd flac-1.2.1/
-configure_args="--enable-shared=no --enable-static=yes --with-ogg=/usr/local $ENABLE_DEBUG"
+configure_args="--enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.2.2~dfsg/inst/usr/local $ENABLE_DEBUG"
 if test $kernel = "Darwin"; then
   configure_args="$configure_args --disable-asm-optimizations"
 fi
@@ -591,34 +716,127 @@ cd ../..
 
 # taglib
 
-cd taglib-1.7/
+cd taglib-1.7.1/
 test -f Makefile || eval cmake -DWITH_ASF=ON -DWITH_MP4=ON -DINCLUDE_DIRECTORIES=/usr/local/include -DLINK_DIRECTORIES=/usr/local/lib -DENABLE_STATIC=ON -DCMAKE_VERBOSE_MAKEFILE=ON $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
 make
 mkdir inst
 make install DESTDIR=`pwd`/inst
+fixcmakeinst
 cd inst
-if test $kernel = "MINGW" && test -d prg; then
-  rm -rf usr
-  mv prg/msys usr
-  rmdir prg
-fi
-tar czf ../../bin/taglib-1.7.tgz usr
+tar czf ../../bin/taglib-1.7.1.tgz usr
+cd ../..
+
+# libav
+
+cd libav-0.8.1
+# configure needs yasm and pr
+# On msys, make >= 3.81 is needed.
+# Most options taken from
+# http://oxygene.sk/lukas/2011/04/minimal-audio-only-ffmpeg-build-with-mingw32/
+# Disable-sse avoids a SEGFAULT under MinGW.
+./configure \
+	--enable-memalign-hack \
+	--disable-shared \
+	--enable-static \
+	--disable-debug \
+	--disable-avdevice \
+	--disable-avfilter \
+	--disable-pthreads \
+	--disable-swscale \
+	--enable-ffmpeg \
+	--disable-network \
+	--disable-muxers \
+	--disable-demuxers \
+	--disable-sse \
+	--enable-rdft \
+	--enable-demuxer=aac \
+	--enable-demuxer=ac3 \
+	--enable-demuxer=ape \
+	--enable-demuxer=asf \
+	--enable-demuxer=flac \
+	--enable-demuxer=matroska_audio \
+	--enable-demuxer=mp3 \
+	--enable-demuxer=mpc \
+	--enable-demuxer=mov \
+	--enable-demuxer=mpc8 \
+	--enable-demuxer=ogg \
+	--enable-demuxer=tta \
+	--enable-demuxer=wav \
+	--enable-demuxer=wv \
+	--disable-bsfs \
+	--disable-filters \
+	--disable-parsers \
+	--enable-parser=aac \
+	--enable-parser=ac3 \
+	--enable-parser=mpegaudio \
+	--disable-protocols \
+	--enable-protocol=file \
+	--disable-indevs \
+	--disable-outdevs \
+	--disable-encoders \
+	--disable-decoders \
+	--enable-decoder=aac \
+	--enable-decoder=ac3 \
+	--enable-decoder=alac \
+	--enable-decoder=ape \
+	--enable-decoder=flac \
+	--enable-decoder=mp1 \
+	--enable-decoder=mp2 \
+	--enable-decoder=mp3 \
+	--enable-decoder=mpc7 \
+	--enable-decoder=mpc8 \
+	--enable-decoder=tta \
+	--enable-decoder=vorbis \
+	--enable-decoder=wavpack \
+	--enable-decoder=wmav1 \
+	--enable-decoder=wmav2 \
+	--enable-decoder=pcm_alaw \
+	--enable-decoder=pcm_dvd \
+	--enable-decoder=pcm_f32be \
+	--enable-decoder=pcm_f32le \
+	--enable-decoder=pcm_f64be \
+	--enable-decoder=pcm_f64le \
+	--enable-decoder=pcm_s16be \
+	--enable-decoder=pcm_s16le \
+	--enable-decoder=pcm_s16le_planar \
+	--enable-decoder=pcm_s24be \
+	--enable-decoder=pcm_daud \
+	--enable-decoder=pcm_s24le \
+	--enable-decoder=pcm_s32be \
+	--enable-decoder=pcm_s32le \
+	--enable-decoder=pcm_s8 \
+	--enable-decoder=pcm_u16be \
+	--enable-decoder=pcm_u16le \
+	--enable-decoder=pcm_u24be \
+	--enable-decoder=pcm_u24le \
+	--enable-decoder=rawvideo
+make
+mkdir inst
+make install DESTDIR=`pwd`/inst
+cd inst
+tar czf ../../bin/libav-0.8.1.tgz usr
+cd ../..
+
+# chromaprint
+
+cd chromaprint-0.6/
+test -f Makefile || eval cmake -DBUILD_EXAMPLES=ON -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=-lz -DFFMPEG_ROOT=$thisdir/libav-0.8.1/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
+mkdir inst
+make install DESTDIR=`pwd`/inst
+fixcmakeinst
+cd inst
+tar czf ../../bin/chromaprint-0.6.tgz usr
 cd ../..
 
 # mp4v2
 
-cd mp4v2-1.9.1/
-# When getting from SVN with svn checkout http://mp4v2.googlecode.com/svn/trunk/ mp4v2-svn
-# libtoolize
-# aclocal
-# automake --add-missing
-# autoconf
-test -f Makefile || ./configure --enable-shared=no --enable-static=yes --disable-gch $ENABLE_DEBUG
-mkdir inst
-make install DESTDIR=`pwd`/inst
-cd inst
-tar czf ../../bin/mp4v2-1.9.1.tgz usr
-cd ../..
+#cd mp4v2-1.9.1+svn479~dfsg0/
+#test -f Makefile || ./configure --enable-shared=no --enable-static=yes --disable-gch
+#mkdir inst
+#make install DESTDIR=`pwd`/inst
+#cd inst
+#tar czf ../../bin/mp4v2-1.9.1+svn479.tgz usr
+#cd ../..
 
 
 # Install to root directory
@@ -632,7 +850,8 @@ if test $kernel = "Linux"; then
     mkdir kid3
     cat >kid3/build.sh <<"EOF"
 BUILDPREFIX=$(cd ..; pwd)/buildroot/usr/local
-cmake -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L$BUILDPREFIX/lib -ltag" -DTAGLIB_CFLAGS:STRING="-I$BUILDPREFIX/include/taglib -DTAGLIB_STATIC" -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=$BUILDPREFIX/bin -DCMAKE_BUILD_TYPE=Debug -DWITH_GCC_PCH=OFF -DWITH_KDE=OFF -DWITH_TUNEPIMP=OFF -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. ../../kid3
+export PKG_CONFIG_PATH=$BUILDPREFIX/lib/pkgconfig
+cmake -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L$BUILDPREFIX/lib -ltag" -DTAGLIB_CFLAGS:STRING="-I$BUILDPREFIX/include/taglib -DTAGLIB_STATIC" -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=$BUILDPREFIX/bin -DFFMPEG_ROOT=$BUILDPREFIX -DCMAKE_BUILD_TYPE=Debug -DWITH_GCC_PCH=OFF -DWITH_KDE=OFF -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. ../../kid3
 EOF
     chmod +x kid3/build.sh
   fi
@@ -640,13 +859,15 @@ elif test $kernel = "Darwin"; then
   sudo chmod go+w ${BUILDROOT}usr/local
 fi
 
-tar xzf bin/zlib-1.2.5.tgz -C $BUILDROOT
+tar xzf bin/zlib-1.2.6.tgz -C $BUILDROOT
 tar xzf bin/libogg-1.2.2.tgz -C $BUILDROOT
 tar xzf bin/libvorbis-1.3.2.tgz -C $BUILDROOT
 tar xzf bin/flac-1.2.1.tgz -C $BUILDROOT
 tar xzf bin/id3lib-3.8.3.tgz -C $BUILDROOT
-tar xzf bin/taglib-1.7.tgz -C $BUILDROOT
-tar xzf bin/mp4v2-1.9.1.tgz -C $BUILDROOT
+tar xzf bin/taglib-1.7.1.tgz -C $BUILDROOT
+tar xzf bin/libav-0.8.1.tgz -C $BUILDROOT
+tar xzf bin/chromaprint-0.6.tgz -C $BUILDROOT
+#tar xzf bin/mp4v2-1.9.1+svn479.tgz -C $BUILDROOT
 
 if test $kernel = "Darwin"; then
   sudo chmod go-w ${BUILDROOT}usr/local
