@@ -1,7 +1,8 @@
-#!/bin/sh
+#!/bin/bash
 
 BASEDIR="../src" # root of translatable sources
 PROJECT="kid3" # project name
+PROJECTVERSION="2.1" # project version
 BUGADDR="http://sourceforge.net/tracker/?group_id=70849&atid=529221" # MSGID-Bugs
 WDIR=`pwd` # working dir
 
@@ -27,9 +28,11 @@ cd ${BASEDIR}
 find . -name '*.cpp' -o -name '*.h' -o -name '*.c' -o -name '*.hpp' | sort > ${WDIR}/infiles.list
 echo "rc.cpp" >> ${WDIR}/infiles.list
 cd ${WDIR}
-xgettext --from-code=UTF-8 -C -kde -ci18n -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 -ki18ncp:1c,2,3 -ktr2i18n:1 \
+xgettext --from-code=UTF-8 -C --kde -ci18n -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 -ki18ncp:1c,2,3 -ktr2i18n:1 \
   -kI18N_NOOP:1 -kI18N_NOOP2:1c,2 -kaliasLocale -kki18n:1 -kki18nc:1c,2 -kki18np:1,2 -kki18ncp:1c,2,3 \
   --msgid-bugs-address="${BUGADDR}" \
+  --package-name="${PROJECT^}" \
+  --package-version="${PROJECTVERSION}" \
   --files-from=infiles.list -D ${BASEDIR} -D ${WDIR} -o ${PROJECT}.pot || { echo "error while calling xgettext. aborting."; exit 1; }
 echo "Done extracting messages"
 
@@ -39,6 +42,7 @@ catalogs=`find . -name '*.po'`
 for cat in $catalogs; do
   echo $cat
   msgmerge --quiet --update --backup=none $cat ${PROJECT}.pot
+  sed -i "/#, qt-format/ d; /#, kde-format/ d; /^#~ msg/ d" $cat
 done
 echo "Done merging translations"
 
