@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Jul 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,6 +26,9 @@
 
 #include "configstore.h"
 #include "config.h"
+#ifndef CONFIG_USE_KDE
+#include "shortcutsmodel.h"
+#endif
 
 MiscConfig ConfigStore::s_miscCfg("General Options");
 ImportConfig ConfigStore::s_genCfg("General Options");
@@ -49,6 +52,7 @@ ConfigStore::ConfigStore()
 #else
   m_config = new Kid3Settings(QSettings::UserScope, "kid3.sourceforge.net", "Kid3");
   m_config->beginGroup("/kid3");
+  m_shortcutsModel = new ShortcutsModel;
 #endif
 }
 
@@ -57,6 +61,9 @@ ConfigStore::ConfigStore()
  */
 ConfigStore::~ConfigStore()
 {
+#ifndef CONFIG_USE_KDE
+  delete m_shortcutsModel;
+#endif
   // m_config is not deleted because this could lead to a crash on Mac OS.
 }
 
@@ -75,7 +82,7 @@ void ConfigStore::writeToConfig()
   s_amazonCfg.writeToConfig(m_config);
   s_filterCfg.writeToConfig(m_config);
   s_playlistCfg.writeToConfig(m_config);
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
   s_musicBrainzCfg.writeToConfig(m_config);
 #endif
 }
@@ -95,7 +102,7 @@ void ConfigStore::readFromConfig()
   s_amazonCfg.readFromConfig(m_config);
   s_filterCfg.readFromConfig(m_config);
   s_playlistCfg.readFromConfig(m_config);
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
   s_musicBrainzCfg.readFromConfig(m_config);
 #endif
 }
