@@ -69,6 +69,9 @@ void FormatConfig::setAsFilenameFormatter()
   m_strRepMap["?"] = "";
   m_strRepMap["*"] = "";
   m_strRepMap["\""] = "''";
+  m_strRepMap["<"] = "-";
+  m_strRepMap[">"] = "-";
+  m_strRepMap["|"] = "-";
   m_strRepMap[QChar(0xe4)] = "ae";
   m_strRepMap[QChar(0xf6)] = "oe";
   m_strRepMap[QChar(0xfc)] = "ue";
@@ -76,6 +79,60 @@ void FormatConfig::setAsFilenameFormatter()
   m_strRepMap[QChar(0xd6)] = "Oe";
   m_strRepMap[QChar(0xdc)] = "Ue";
   m_strRepMap[QChar(0xdf)] = "ss";
+  m_strRepMap[QChar(0xc0)] = "A";
+  m_strRepMap[QChar(0xc1)] = "A";
+  m_strRepMap[QChar(0xc2)] = "A";
+  m_strRepMap[QChar(0xc3)] = "A";
+  m_strRepMap[QChar(0xc5)] = "A";
+  m_strRepMap[QChar(0xc6)] = "AE";
+  m_strRepMap[QChar(0xc7)] = "C";
+  m_strRepMap[QChar(0xc8)] = "E";
+  m_strRepMap[QChar(0xc9)] = "E";
+  m_strRepMap[QChar(0xca)] = "E";
+  m_strRepMap[QChar(0xcb)] = "E";
+  m_strRepMap[QChar(0xcc)] = "I";
+  m_strRepMap[QChar(0xcd)] = "I";
+  m_strRepMap[QChar(0xce)] = "I";
+  m_strRepMap[QChar(0xcf)] = "I";
+  m_strRepMap[QChar(0xd0)] = "D";
+  m_strRepMap[QChar(0xd1)] = "N";
+  m_strRepMap[QChar(0xd2)] = "O";
+  m_strRepMap[QChar(0xd3)] = "O";
+  m_strRepMap[QChar(0xd4)] = "O";
+  m_strRepMap[QChar(0xd5)] = "O";
+  m_strRepMap[QChar(0xd7)] = "x";
+  m_strRepMap[QChar(0xd8)] = "O";
+  m_strRepMap[QChar(0xd9)] = "U";
+  m_strRepMap[QChar(0xda)] = "U";
+  m_strRepMap[QChar(0xdb)] = "U";
+  m_strRepMap[QChar(0xdd)] = "Y";
+  m_strRepMap[QChar(0xe0)] = "a";
+  m_strRepMap[QChar(0xe1)] = "a";
+  m_strRepMap[QChar(0xe2)] = "a";
+  m_strRepMap[QChar(0xe3)] = "a";
+  m_strRepMap[QChar(0xe5)] = "a";
+  m_strRepMap[QChar(0xe6)] = "ae";
+  m_strRepMap[QChar(0xe7)] = "c";
+  m_strRepMap[QChar(0xe8)] = "e";
+  m_strRepMap[QChar(0xe9)] = "e";
+  m_strRepMap[QChar(0xea)] = "e";
+  m_strRepMap[QChar(0xeb)] = "e";
+  m_strRepMap[QChar(0xec)] = "i";
+  m_strRepMap[QChar(0xed)] = "i";
+  m_strRepMap[QChar(0xee)] = "i";
+  m_strRepMap[QChar(0xef)] = "i";
+  m_strRepMap[QChar(0xf0)] = "d";
+  m_strRepMap[QChar(0xf1)] = "n";
+  m_strRepMap[QChar(0xf2)] = "o";
+  m_strRepMap[QChar(0xf3)] = "o";
+  m_strRepMap[QChar(0xf4)] = "o";
+  m_strRepMap[QChar(0xf5)] = "o";
+  m_strRepMap[QChar(0xf8)] = "o";
+  m_strRepMap[QChar(0xf9)] = "u";
+  m_strRepMap[QChar(0xfa)] = "u";
+  m_strRepMap[QChar(0xfb)] = "u";
+  m_strRepMap[QChar(0xfd)] = "y";
+  m_strRepMap[QChar(0xff)] = "y";
 }
 
 /**
