@@ -25,6 +25,7 @@
  */
 
 #include "discogsimporter.h"
+#include <QUrl>
 #include "serverimporterconfig.h"
 #include "trackdatamodel.h"
 #include "configstore.h"
@@ -36,12 +37,12 @@ static const char discogsServer[] = "www.discogs.com:80";
 /**
  * Constructor.
  *
- * @param parent          parent object
+ * @param netMgr network access manager
  * @param trackDataModel track data to be filled with imported values
  */
-DiscogsImporter::DiscogsImporter(QObject* parent,
+DiscogsImporter::DiscogsImporter(QNetworkAccessManager* netMgr,
                                  TrackDataModel* trackDataModel) :
-  ServerImporter(parent, trackDataModel)
+  ServerImporter(netMgr, trackDataModel)
 {
   setObjectName("DiscogsImporter");
 }
@@ -76,14 +77,21 @@ bool DiscogsImporter::additionalTags() const { return true; }
 void DiscogsImporter::parseFindResults(const QByteArray& searchStr)
 {
   // releases have the format:
-  // <div><a href="/Amon-Amarth-The-Avenger/release/398878"><em>Amon</em> <em>Amarth</em> - <em>The</em> <em>Avenger</em></a></div>
+  // <div class="data">
+  // <div>
+  //     <a href="/Amon-Amarth-The-Avenger/release/398878">
+  //         <em>Amon</em> <em>Amarth</em> - <em>The</em> <em>Avenger</em>
+  //     </a>
+  // </div>
   QString str = QString::fromUtf8(searchStr);
-  QRegExp idTitleRe("<a href=\"/([^/]*/?release)/([0-9]+)\">(.+)</a>");
-  QStringList lines = str.remove('\r').split("\n");
+  QRegExp idTitleRe("class=\"data\".*<a href=\"/([^/]*/?release)/([0-9]+)\">(.+)</a>");
+  QStringList lines = str.remove('\r').split(QRegExp("\\n{2,}"));
   m_albumListModel->clear();
   for (QStringList::const_iterator it = lines.begin(); it != lines.end(); ++it) {
-    if (idTitleRe.indexIn(*it) != -1) {
-      QString title(idTitleRe.cap(3));
+    QString line(*it);
+    line.remove('\n');
+    if (idTitleRe.indexIn(line) != -1) {
+      QString title(idTitleRe.cap(3).trimmed());
       title.replace(QRegExp("<[^>]+>"), "");
       if (!title.isEmpty()) {
         m_albumListModel->appendRow(new AlbumListItem(
@@ -384,14 +392,16 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
     /*
      * credits can be found in "Credits"
      */
-    start = str.indexOf("<h1>Credits</h1>");
+    start = str.indexOf(">Credits</h");
     if (start >= 0) {
-      start += 16; // skip "Credits"
+      start += 13; // skip "Credits" plus end of element (e.g. "3>")
       end = str.indexOf("</div>", start + 1);
       if (end > start) {
         QString creditsStr = str.mid(start, end - start);
         creditsStr.replace(nlSpaceRe, ""); // strip new lines and space after them
         creditsStr.replace("<br />", "\n");
+        creditsStr.replace("</li>", "\n");
+        creditsStr.replace("&ndash;", " - ");
         creditsStr = removeHtml(creditsStr); // strip HTML tags and entities
         parseCredits(creditsStr, framesHdr);
       }
@@ -445,6 +455,7 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
       FrameCollection frames(framesHdr);
       QRegExp posRe("<td [^>]*class=\"track_pos\">(\\d+)</td>");
       QRegExp artistsRe("<td class=\"track_artists\"><a href=\"/artist/[^>]+>([^<]+)</a>");
+      QRegExp moreArtistsRe("^([^<>]+)<a href=\"/artist/[^>]+>([^<]+)</a>");
       QRegExp titleRe("class=\"track_title\"[^>]*>([^<]+)<");
       QRegExp durationRe("<td [^>]*class=\"track_duration\"[^>]*>(?:<span>)?(\\d+):(\\d+)</");
       QRegExp indexRe("<td class=\"track_index\">([^<]+)$");
@@ -472,8 +483,20 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
           if (artistsRe.indexIn(trackDataStr) >= 0) {
             // use the artist in the header as the album artist
             // and the artist in the track as the artist
-            frames.setArtist(
-              fixUpArtist(artistsRe.cap(1)));
+            QString artist(fixUpArtist(artistsRe.cap(1)));
+            // Look if there are more artists
+            int artistEndPos = artistsRe.pos() + artistsRe.matchedLength();
+            while (moreArtistsRe.indexIn(
+                     trackDataStr, artistEndPos, QRegExp::CaretAtOffset) >=
+                   artistEndPos) {
+              artist += moreArtistsRe.cap(1);
+              artist += fixUpArtist(moreArtistsRe.cap(2));
+              int endPos = moreArtistsRe.pos() + moreArtistsRe.matchedLength();
+              if (endPos <= artistEndPos) // must be true for regexp
+                break;
+              artistEndPos = endPos;
+            }
+            frames.setArtist(artist);
             frames.setValue(Frame::FT_AlbumArtist, framesHdr.getArtist());
           }
         }
@@ -492,11 +515,17 @@ void DiscogsImporter::parseAlbumResults(const QByteArray& albumStr)
             blockquoteStart += 12;
             int blockquoteEnd = trackDataStr.indexOf("</blockquote>",
                                                      blockquoteStart);
+            if (blockquoteEnd == -1) {
+              // If the element is not correctly closed, search for </span>
+              blockquoteEnd = trackDataStr.indexOf("</span>", blockquoteStart);
+            }
             if (blockquoteEnd > blockquoteStart) {
               QString blockquoteStr(trackDataStr.mid(blockquoteStart,
                 blockquoteEnd - blockquoteStart));
               // additional track info like "Music By, Lyrics By - "
               blockquoteStr.replace("<br />", "\n");
+              blockquoteStr.replace("</li>", "\n");
+              blockquoteStr.replace("&ndash;", " - ");
               blockquoteStr = removeHtml(blockquoteStr);
               parseCredits(blockquoteStr, frames);
             }
@@ -566,7 +595,7 @@ void DiscogsImporter::sendFindQuery(
    */
   sendRequest(discogsServer,
               QString("/search?type=releases&q=") +
-              encodeUrlQuery(artist + " " + album) + "&btn=Search", true);
+              encodeUrlQuery(artist + " " + album) + "&btn=Search");
 }
 
 /**
@@ -584,5 +613,6 @@ void DiscogsImporter::sendTrackListQuery(
    * Query looks like this:
    * http://www.discogs.com/release/761529
    */
-  sendRequest(discogsServer, QString("/") + cat + '/' + id, true);
+  sendRequest(discogsServer, QString("/") + QUrl::toPercentEncoding(cat) + '/'
+              + id);
 }
