@@ -29,6 +29,13 @@
 #include "genres.h"
 #include "qtcompatmac.h"
 
+/**
+ * Constructor.
+ */
+ImportParser::ImportParser() : m_trackIncrEnabled(false), m_trackIncrNr(0)
+{
+}
+
 /**
  * Get help text for format codes supported by setFormat().
  *
