@@ -29,6 +29,7 @@
 
 #include <QDialog>
 #include <QTextEdit>
+#include "kid3api.h"
 
 class QProcess;
 class QString;
@@ -38,7 +39,7 @@ class TaggedFile;
 /**
  * Handler for external process.
  */
-class ExternalProcess : public QObject {
+class KID3_CORE_EXPORT ExternalProcess : public QObject {
 Q_OBJECT
 
 public:
@@ -62,9 +63,7 @@ public:
     /**
      * Append text.
      */
-    void append(const QString& text) {
-      m_textEdit->append(text);
-    }
+    void append(const QString& text);
 
     /**
      * Scroll text to bottom.
@@ -105,11 +104,6 @@ private slots:
    */
   void readFromStdout();
 
-  /**
-   * Read data from standard error and display it in the output viewer.
-   */
-  void readFromStderr();
-
 private:
   QWidget* m_parent;
   QProcess* m_process;
