@@ -32,15 +32,16 @@
 #include <QSet>
 #include <QFileInfo>
 #include <QStringList>
+#include "taggedfile.h"
+#include "kid3api.h"
 
 class QFileSystemModel;
-class TaggedFile;
 class TaggedFileIconProvider;
 
 /**
  * Proxy for filesystem model which filters files.
  */
-class FileProxyModel : public QSortFilterProxyModel {
+class KID3_CORE_EXPORT FileProxyModel : public QSortFilterProxyModel {
   Q_OBJECT
 public:
   /** Custom role, extending QFileSystemModel::Roles. */
@@ -200,14 +201,6 @@ public:
    */
   static QString getPathIfIndexOfDir(const QModelIndex& index);
 
-  /**
-   * Release a tagged file or directory index from an index.
-   * If the index has a TaggedFile, it will be deleted.
-   *
-   * @param index model index
-   */
-  static void releaseTaggedFileOfIndex(const QModelIndex& index);
-
   /**
    * Read tagged file with TagLib.
    *
