@@ -30,6 +30,7 @@
 #include <QTextCodec>
 #include <QUrl>
 #include <QTextStream>
+#include <QNetworkAccessManager>
 #ifdef CONFIG_USE_KDE
 #include <kapplication.h>
 #else
@@ -37,6 +38,7 @@
 #endif
 #ifdef HAVE_QTDBUS
 #include <QDBusConnection>
+#include <unistd.h>
 #include "scriptinterface.h"
 #endif
 #include "fileproxymodel.h"
@@ -59,6 +61,9 @@
 #include "discogsimporter.h"
 #include "amazonimporter.h"
 #include "qtcompatmac.h"
+#ifdef HAVE_CHROMAPRINT
+#include "musicbrainzclient.h"
+#endif
 #ifdef HAVE_PHONON
 #include "audioplayer.h"
 #endif
@@ -97,13 +102,15 @@ Kid3Application::Kid3Application(QObject* parent) : QObject(parent),
   m_framesV2SelectionModel(new QItemSelectionModel(m_framesV2Model, this)),
   m_framelist(new FrameList(m_framesV2Model, m_framesV2SelectionModel)),
   m_configStore(new ConfigStore),
-  m_downloadClient(new DownloadClient(this)),
+  m_netMgr(new QNetworkAccessManager(this)),
+  m_downloadClient(new DownloadClient(m_netMgr)),
   m_textExporter(new TextExporter(this)),
   m_dirRenamer(new DirRenamer(this)),
 #ifdef HAVE_PHONON
   m_player(0),
 #endif
-  m_downloadImageDest(ImageForSelectedFiles)
+  m_downloadImageDest(ImageForSelectedFiles),
+  m_musicBrainzClient(0)
 {
   setObjectName("Kid3Application");
   m_fileProxyModel->setSourceModel(m_fileSystemModel);
@@ -119,11 +126,14 @@ Kid3Application::Kid3Application(QObject* parent) : QObject(parent),
   ConfigStore::s_fnFormatCfg.setAsFilenameFormatter();
 
   m_importers
-      << new FreedbImporter(this, m_trackDataModel)
-      << new TrackTypeImporter(this, m_trackDataModel)
-      << new DiscogsImporter(this, m_trackDataModel)
-      << new AmazonImporter(this, m_trackDataModel)
-      << new MusicBrainzReleaseImporter(this, m_trackDataModel);
+      << new FreedbImporter(m_netMgr, m_trackDataModel)
+      << new TrackTypeImporter(m_netMgr, m_trackDataModel)
+      << new DiscogsImporter(m_netMgr, m_trackDataModel)
+      << new AmazonImporter(m_netMgr, m_trackDataModel)
+      << new MusicBrainzReleaseImporter(m_netMgr, m_trackDataModel);
+#ifdef HAVE_CHROMAPRINT
+  m_musicBrainzClient = new MusicBrainzClient(m_netMgr, m_trackDataModel);
+#endif
 
 #ifdef HAVE_QTDBUS
   if (QDBusConnection::sessionBus().isConnected()) {
@@ -214,7 +224,7 @@ void Kid3Application::readConfig()
 {
   m_configStore->readFromConfig();
   if (ConfigStore::s_miscCfg.m_nameFilter.isEmpty()) {
-    createFilterString(&ConfigStore::s_miscCfg.m_nameFilter);
+    ConfigStore::s_miscCfg.m_nameFilter = createFilterString();
   }
   setTextEncodings();
   if (ConfigStore::s_freedbCfg.m_server == "freedb2.org:80") {
@@ -251,7 +261,8 @@ bool Kid3Application::openDirectory(QString dir, bool fileCheck)
     dir = QDir(dir).absolutePath();
   }
 
-  QStringList nameFilters(ConfigStore::s_miscCfg.m_nameFilter.split(' '));
+  QStringList nameFilters(ConfigStore::s_miscCfg.getNameFilterPatterns().
+                          split(' '));
   m_fileProxyModel->setNameFilters(nameFilters);
   m_fileSystemModel->setFilter(QDir::AllEntries | QDir::AllDirs);
   QModelIndex rootIndex = m_fileSystemModel->setRootPath(dir);
@@ -1737,99 +1748,42 @@ QString Kid3Application::getImageUrl(const QString& url)
   return imgurl;
 }
 
-#ifndef WIN32
-/**
- * Get all combinations with lower- and uppercase characters.
- *
- * @param str original string
- *
- * @return string with all combinations, separated by spaces.
- */
-static QString lowerUpperCaseCombinations(const QString& str)
-{
-  QString result;
-  QString lc(str.toLower());
-  QString uc(str.toUpper());
-
-  // get a mask of all alphabetic characters in the string
-  unsigned char numChars = 0, charMask = 0, posMask = 1;
-  int numPos = lc.length();
-  if (numPos > 8) numPos = 8;
-  for (int pos = 0; pos < numPos; ++pos, posMask <<= 1) {
-    if (lc[pos] >= 'a' && lc[pos] <= 'z') {
-      charMask |= posMask;
-      ++numChars;
-    }
-  }
-
-  int numCombinations = 1 << numChars;
-  for (int comb = 0; comb < numCombinations; ++comb) {
-    posMask = 1;
-    int combMask = 1;
-    if (!result.isEmpty()) {
-      result += ' ';
-    }
-    for (int pos = 0; pos < numPos; ++pos, posMask <<= 1) {
-      if (charMask & posMask) {
-        if (comb & combMask) {
-          result += uc[pos];
-        } else {
-          result += lc[pos];
-        }
-        combMask <<= 1;
-      } else {
-        result += lc[pos];
-      }
-    }
-  }
-
-  return result;
-}
-#endif
-
 /**
  * Create a filter string for the file dialog.
  * The filter string contains entries for all supported types.
  *
- * @param defaultNameFilter if not 0, return default name filter here
- *
  * @return filter string.
  */
-QString Kid3Application::createFilterString(QString* defaultNameFilter) const
+QString Kid3Application::createFilterString() const
 {
   QStringList extensions = TaggedFile::getSupportedFileExtensions();
-  QString result, allCombinations;
+  QString result, allPatterns;
   for (QStringList::const_iterator it = extensions.begin();
        it != extensions.end();
        ++it) {
     QString text = (*it).mid(1).toUpper();
-    QString lowerExt = '*' + *it;
-#ifdef WIN32
-    const QString& combinations = lowerExt;
-#else
-    QString combinations = lowerUpperCaseCombinations(lowerExt);
-#endif
-    if (!allCombinations.isEmpty()) {
-      allCombinations += ' ';
+    QString pattern = '*' + *it;
+    if (!allPatterns.isEmpty()) {
+      allPatterns += ' ';
     }
-    allCombinations += combinations;
+    allPatterns += pattern;
 #ifdef CONFIG_USE_KDE
-    result += combinations;
+    result += pattern;
     result += '|';
     result += text;
     result += " (";
-    result += lowerExt;
+    result += pattern;
     result += ")\n";
 #else
     result += text;
     result += " (";
-    result += combinations;
+    result += pattern;
     result += ");;";
 #endif
   }
 
 #ifdef CONFIG_USE_KDE
-  QString allExt = allCombinations;
+  QString allExt = allPatterns;
   allExt += '|';
   allExt += i18n("All Supported Files");
   allExt += '\n';
@@ -1837,15 +1791,11 @@ QString Kid3Application::createFilterString(QString* defaultNameFilter) const
 #else
   QString allExt = i18n("All Supported Files");
   allExt += " (";
-  allExt += allCombinations;
+  allExt += allPatterns;
   allExt += ");;";
   result = allExt + result + i18n("All Files (*)");
 #endif
 
-  if (defaultNameFilter) {
-    *defaultNameFilter = allCombinations;
-  }
-
   return result;
 }
 
