@@ -38,6 +38,7 @@
 class QFileSystemModel;
 class QItemSelectionModel;
 class QModelIndex;
+class QNetworkAccessManager;
 class FileProxyModel;
 class DirProxyModel;
 class TrackDataModel;
@@ -49,6 +50,7 @@ class TaggedFile;
 class FrameList;
 class IFrameEditor;
 class ServerImporter;
+class MusicBrainzClient;
 class TextExporter;
 class DirRenamer;
 #ifdef HAVE_PHONON
@@ -58,7 +60,7 @@ class AudioPlayer;
 /**
  * Kid3 application logic, independent of GUI.
  */
-class Kid3Application : public QObject {
+class KID3_CORE_EXPORT Kid3Application : public QObject {
   Q_OBJECT
 public:
   /** Destination for downloadImage(). */
@@ -146,6 +148,12 @@ public:
    */
   Kid3Settings* getSettings() const;
 
+  /**
+   * Get configuration.
+   * @return configuration.
+   */
+  ConfigStore* getConfigStore() const { return m_configStore; }
+
   /**
    * Get download client.
    * @return download client.
@@ -164,6 +172,12 @@ public:
    */
   QList<ServerImporter*> getServerImporters() { return m_importers; }
 
+  /**
+   * Get MusicBrainz client.
+   * @return MusicBrainz client if supported, else 0
+   */
+  MusicBrainzClient* getMusicBrainzClient() { return m_musicBrainzClient; }
+
   /**
    * Get directory renamer.
    * @return directory renamer.
@@ -384,11 +398,9 @@ public:
    * Create a filter string for the file dialog.
    * The filter string contains entries for all supported types.
    *
-   * @param defaultNameFilter if not 0, return default name filter here
-   *
    * @return filter string.
    */
-  QString createFilterString(QString* defaultNameFilter = 0) const;
+  QString createFilterString() const;
 
   /**
    * Get image destination set by downloadImage().
@@ -853,6 +865,8 @@ private:
   FrameList* m_framelist;
   /** Configuration */
   ConfigStore* m_configStore;
+  /** Network access manager */
+  QNetworkAccessManager* m_netMgr;
   /** Download client */
   DownloadClient* m_downloadClient;
   /** Text exporter */
@@ -879,7 +893,8 @@ private:
   QString m_tagsToFilenameFormat;
   /** Importers for different servers */
   QList<ServerImporter*> m_importers;
-
+  /** Importer for MusicBrainz fingerprints */
+  MusicBrainzClient* m_musicBrainzClient;
   /** Current directory */
   static QString s_dirName;
 };
