@@ -32,6 +32,7 @@
 #include "configstore.h"
 #include "genres.h"
 #include "modeliterator.h"
+#include "saferename.h"
 
 QList<const TaggedFile::Resolver*> TaggedFile::s_resolvers;
 
@@ -357,7 +358,8 @@ void TaggedFile::getTagsFromFilename(FrameCollection& frames, const QString& fmt
     { "%g", "%\\{genre\\}" },
     { "%\\{year\\}", "%\\{date\\}" },
     { "%\\{track\\}", "%\\{track number\\}" },
-    { "%\\{tracknumber\\}", "%\\{track number\\}" }
+    { "%\\{tracknumber\\}", "%\\{track number\\}" },
+    { "%\\{discnumber\\}", "%\\{disc number\\}" }
   };
   int percentIdx = 0, nr = 1;
   for (unsigned i = 0; i < sizeof(codeToName) / sizeof(codeToName[0]); ++i) {
@@ -372,7 +374,8 @@ void TaggedFile::getTagsFromFilename(FrameCollection& frames, const QString& fmt
       QString code =
         pattern.mid(percentIdx + 3, closingBracePos - percentIdx - 3).toLower();
       codePos[code] = nr++;
-      if (code == "track number" || code == "date") {
+      if (code == "track number" || code == "date" || code == "disc number" ||
+          code == "bpm") {
         pattern.replace(percentIdx, closingBracePos - percentIdx + 2, "(\\d{1,4})");
         percentIdx += 9;
       } else {
@@ -516,12 +519,12 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
     // insensitive filesystems (e.g. Windows).
     QString temp_filename(fnNew);
     temp_filename.append("_CASE");
-    if (!QDir(m_dirname).rename(fnOld, temp_filename)) {
+    if (!Utils::safeRename(m_dirname, fnOld, temp_filename)) {
       qDebug("rename(%s, %s) failed", fnOld.toLatin1().data(),
              temp_filename.toLatin1().data());
       return false;
     }
-    if (!QDir(m_dirname).rename(temp_filename, fnNew)) {
+    if (!Utils::safeRename(m_dirname, temp_filename, fnNew)) {
       qDebug("rename(%s, %s) failed", temp_filename.toLatin1().data(),
              fnNew.toLatin1().data());
       return false;
@@ -530,7 +533,7 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
     qDebug("rename(%s, %s): %s already exists", fnOld.toLatin1().data(),
            fnNew.toLatin1().data(), fnNew.toLatin1().data());
     return false;
-  } else if (!QDir(m_dirname).rename(fnOld, fnNew)) {
+  } else if (!Utils::safeRename(m_dirname, fnOld, fnNew)) {
     qDebug("rename(%s, %s) failed", fnOld.toLatin1().data(),
            fnNew.toLatin1().data());
     return false;
@@ -1039,6 +1042,17 @@ void TaggedFile::getAllFramesV2(FrameCollection& frames)
   }
 }
 
+/**
+ * Close any file handles which are held open by the tagged file object.
+ * The default implementation does nothing. If a concrete subclass holds
+ * any file handles open, it has to close them in this method. This method
+ * can be used before operations which require that a file is not open,
+ * e.g. file renaming on Windows.
+ */
+void TaggedFile::closeFileHandle()
+{
+}
+
 /**
  * Set frames in tag 2.
  *
