@@ -27,6 +27,8 @@
 #ifndef MOVETOTRASH_H
 #define MOVETOTRASH_H
 
+#include "kid3api.h"
+
 class QString;
 
 namespace Utils {
@@ -38,7 +40,7 @@ namespace Utils {
    *
    * @return true if ok.
    */
-  bool moveToTrash(const QString& path);
+  bool KID3_CORE_EXPORT moveToTrash(const QString& path);
 
 }
 
