@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jun 2009
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -46,6 +46,7 @@
 #include <kfiledialog.h>
 #else
 #include <QFileDialog>
+#include "configstore.h"
 #endif
 
 /** QTextEdit with label above */
@@ -225,13 +226,11 @@ LabeledTextEdit::LabeledTextEdit(QWidget* parent) :
   QVBoxLayout* layout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   m_edit = new QTextEdit(this);
-  if (layout && m_label && m_edit) {
-    layout->setMargin(0);
-    layout->setSpacing(2);
-    m_edit->setAcceptRichText(false);
-    layout->addWidget(m_label);
-    layout->addWidget(m_edit);
-  }
+  layout->setMargin(0);
+  layout->setSpacing(2);
+  m_edit->setAcceptRichText(false);
+  layout->addWidget(m_label);
+  layout->addWidget(m_edit);
 }
 
 /**
@@ -246,12 +245,10 @@ LabeledLineEdit::LabeledLineEdit(QWidget* parent) :
   QVBoxLayout* layout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   m_edit = new QLineEdit(this);
-  if (layout && m_label && m_edit) {
-    layout->setMargin(0);
-    layout->setSpacing(2);
-    layout->addWidget(m_label);
-    layout->addWidget(m_edit);
-  }
+  layout->setMargin(0);
+  layout->setSpacing(2);
+  layout->addWidget(m_label);
+  layout->addWidget(m_edit);
 }
 
 /**
@@ -267,17 +264,15 @@ LabeledComboBox::LabeledComboBox(QWidget* parent,
   QVBoxLayout* layout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   m_combo = new QComboBox(this);
-  if (layout && m_label && m_combo) {
-    layout->setMargin(0);
-    layout->setSpacing(2);
-    QStringList strList;
-    while (*strlst) {
-      strList += QCM_translate(*strlst++);
-    }
-    m_combo->addItems(strList);
-    layout->addWidget(m_label);
-    layout->addWidget(m_combo);
+  layout->setMargin(0);
+  layout->setSpacing(2);
+  QStringList strList;
+  while (*strlst) {
+    strList += QCM_translate(*strlst++);
   }
+  m_combo->addItems(strList);
+  layout->addWidget(m_label);
+  layout->addWidget(m_combo);
 }
 
 /**
@@ -338,7 +333,7 @@ public:
    * @param field field to edit
    */
   TextFieldControl(Frame::Field& field) :
-    Mp3FieldControl(field) {}
+    Mp3FieldControl(field), m_edit(0) {}
 
   /**
    * Destructor.
@@ -372,7 +367,7 @@ public:
    * @param field field to edit
    */
   LineFieldControl(Frame::Field& field) :
-    Mp3FieldControl(field) {}
+    Mp3FieldControl(field), m_edit(0) {}
 
   /**
    * Destructor.
@@ -406,7 +401,7 @@ public:
    * @param field field to edit
    */
   IntFieldControl(Frame::Field& field) :
-    Mp3FieldControl(field) {}
+    Mp3FieldControl(field), m_numInp(0) {}
 
   /**
    * Destructor.
@@ -442,7 +437,7 @@ public:
    */
   IntComboBoxControl(Frame::Field& field,
                      const char **lst) :
-    Mp3FieldControl(field), m_strLst(lst) {}
+    Mp3FieldControl(field), m_ptInp(0), m_strLst(lst) {}
 
   /**
    * Destructor.
@@ -481,7 +476,7 @@ public:
    */
   BinFieldControl(Frame::Field& field,
                   const Frame& frame, const TaggedFile* taggedFile) :
-    Mp3FieldControl(field), m_frame(frame), m_taggedFile(taggedFile) {}
+    Mp3FieldControl(field), m_bos(0), m_frame(frame), m_taggedFile(taggedFile) {}
 
   /**
    * Destructor.
@@ -529,21 +524,19 @@ BinaryOpenSave::BinaryOpenSave(QWidget* parent, const Frame::Field& field) :
   QPushButton* openButton = new QPushButton(i18n("&Import"), this);
   QPushButton* saveButton = new QPushButton(i18n("&Export"), this);
   QPushButton* viewButton = new QPushButton(i18n("&View"), this);
-  if (layout && m_label && m_clipButton && openButton && saveButton && viewButton) {
-    layout->setMargin(0);
-    layout->setSpacing(6);
-    layout->addWidget(m_label);
-    layout->addWidget(m_clipButton);
-    layout->addWidget(openButton);
-    layout->addWidget(saveButton);
-    layout->addWidget(viewButton);
-    connect(m_clipButton, SIGNAL(clicked()), this, SLOT(clipData()));
-    connect(openButton, SIGNAL(clicked()), this, SLOT(loadData()));
-    connect(saveButton, SIGNAL(clicked()), this, SLOT(saveData()));
-    connect(viewButton, SIGNAL(clicked()), this, SLOT(viewData()));
-    connect(QApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(setClipButtonState()));
-    setClipButtonState();
-  }
+  layout->setMargin(0);
+  layout->setSpacing(6);
+  layout->addWidget(m_label);
+  layout->addWidget(m_clipButton);
+  layout->addWidget(openButton);
+  layout->addWidget(saveButton);
+  layout->addWidget(viewButton);
+  connect(m_clipButton, SIGNAL(clicked()), this, SLOT(clipData()));
+  connect(openButton, SIGNAL(clicked()), this, SLOT(loadData()));
+  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveData()));
+  connect(viewButton, SIGNAL(clicked()), this, SLOT(viewData()));
+  connect(QApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(setClipButtonState()));
+  setClipButtonState();
 }
 
 /**
@@ -585,28 +578,24 @@ void BinaryOpenSave::loadData()
 #ifdef CONFIG_USE_KDE
   QString loadfilename = KFileDialog::getOpenFileName(
     m_defaultDir.isEmpty() ? Kid3Application::getDirName() : m_defaultDir,
-    QString::null, this);
+    m_filter, this);
 #else
   QString loadfilename = QFileDialog::getOpenFileName(
     this, QString(),
-    m_defaultDir.isEmpty() ? Kid3Application::getDirName() : m_defaultDir
-#if !defined Q_OS_WIN32 && !defined Q_OS_MAC
-    , QString(), 0, QFileDialog::DontUseNativeDialog
-#endif
-    );
+    m_defaultDir.isEmpty() ? Kid3Application::getDirName() : m_defaultDir,
+    m_filter, 0, ConfigStore::s_miscCfg.m_dontUseNativeDialogs
+    ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
 #endif
   if (!loadfilename.isEmpty()) {
     QFile file(loadfilename);
     if (file.open(QIODevice::ReadOnly)) {
       size_t size = file.size();
       char* data = new char[size];
-      if (data) {
-        QDataStream stream(&file);
-        stream.readRawData(data, size);
-        m_byteArray = QByteArray(data, size);
-        m_isChanged = true;
-        delete [] data;
-      }
+      QDataStream stream(&file);
+      stream.readRawData(data, size);
+      m_byteArray = QByteArray(data, size);
+      m_isChanged = true;
+      delete [] data;
       file.close();
     }
   }
@@ -626,13 +615,11 @@ void BinaryOpenSave::saveData()
     dir += m_defaultFile;
   }
 #ifdef CONFIG_USE_KDE
-  QString fn = KFileDialog::getSaveFileName(dir, QString::null, this);
+  QString fn = KFileDialog::getSaveFileName(dir, m_filter, this);
 #else
-  QString fn = QFileDialog::getSaveFileName(this, QString(), dir
-#if !defined Q_OS_WIN32 && !defined Q_OS_MAC
-    , QString(), 0, QFileDialog::DontUseNativeDialog
-#endif
-    );
+  QString fn = QFileDialog::getSaveFileName(this, QString(), dir,
+    m_filter, 0, ConfigStore::s_miscCfg.m_dontUseNativeDialogs
+    ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
 #endif
   if (!fn.isEmpty()) {
     QFile file(fn);
@@ -738,10 +725,8 @@ void LineFieldControl::updateTag()
 QWidget* LineFieldControl::createWidget(QWidget* parent)
 {
   m_edit = new LabeledLineEdit(parent);
-  if (m_edit) {
-    m_edit->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
-    m_edit->setText(m_field.m_value.toString());
-  }
+  m_edit->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_edit->setText(m_field.m_value.toString());
   return m_edit;
 }
 
@@ -762,10 +747,8 @@ void IntFieldControl::updateTag()
 QWidget* IntFieldControl::createWidget(QWidget* parent)
 {
   m_numInp = new LabeledSpinBox(parent);
-  if (m_numInp) {
-    m_numInp->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
-    m_numInp->setValue(m_field.m_value.toInt());
-  }
+  m_numInp->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_numInp->setValue(m_field.m_value.toInt());
   return m_numInp;
 }
 
@@ -786,10 +769,8 @@ void IntComboBoxControl::updateTag()
 QWidget* IntComboBoxControl::createWidget(QWidget* parent)
 {
   m_ptInp = new LabeledComboBox(parent, m_strLst);
-  if (m_ptInp) {
-    m_ptInp->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
-    m_ptInp->setCurrentItem(m_field.m_value.toInt());
-  }
+  m_ptInp->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_ptInp->setCurrentItem(m_field.m_value.toInt());
   return m_ptInp;
 }
 
@@ -812,14 +793,20 @@ void BinFieldControl::updateTag()
 QWidget* BinFieldControl::createWidget(QWidget* parent)
 {
   m_bos = new BinaryOpenSave(parent, m_field);
-  if (m_bos) {
-    m_bos->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
-    if (m_taggedFile) {
-      m_bos->setDefaultDir(m_taggedFile->getDirname());
-    }
-    if (m_frame.getType() == Frame::FT_Picture) {
-      m_bos->setDefaultFile("folder.jpg");
-    }
+  m_bos->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  if (m_taggedFile) {
+    m_bos->setDefaultDir(m_taggedFile->getDirname());
+  }
+  if (m_frame.getType() == Frame::FT_Picture) {
+    m_bos->setDefaultFile("folder.jpg");
+    m_bos->setFilter(
+#ifdef CONFIG_USE_KDE
+          "*.jpg *.jpeg *.png|" +
+          i18n("Images (*.jpg *.jpeg *.png)") + "\n*|" + i18n("All Files (*)")
+#else
+          i18n("Images (*.jpg *.jpeg *.png)") + ";;" + i18n("All Files (*)")
+#endif
+          );
   }
   return m_bos;
 }
@@ -859,153 +846,126 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
   qDeleteAll(m_fieldcontrols);
   m_fieldcontrols.clear();
   QVBoxLayout* vlayout = new QVBoxLayout(this);
-  if (vlayout) {
-    vlayout->setSpacing(6);
-    vlayout->setMargin(6);
+  vlayout->setSpacing(6);
+  vlayout->setMargin(6);
 
-    for (Frame::FieldList::iterator fldIt = m_fields.begin();
-         fldIt != m_fields.end();
-         ++fldIt) {
-      Frame::Field& fld = *fldIt;
-      switch (fld.m_value.type()) {
-        case QVariant::Int:
-        case QVariant::UInt:
-          if (fld.m_id == Frame::Field::ID_TextEnc) {
-            static const char* strlst[] = {
-              I18N_NOOP("ISO-8859-1"),
-              I18N_NOOP("UTF16"),
-              I18N_NOOP("UTF16BE"),
-              I18N_NOOP("UTF8"),
-              NULL
-            };
-            IntComboBoxControl* cbox =
-              new IntComboBoxControl(fld, strlst);
-            if (cbox) {
-              m_fieldcontrols.append(cbox);
-            }
-          }
-          else if (fld.m_id == Frame::Field::ID_PictureType) {
-            static const char* strlst[] = {
-              I18N_NOOP("Other"),
-              I18N_NOOP("32x32 pixels PNG file icon"),
-              I18N_NOOP("Other file icon"),
-              I18N_NOOP("Cover (front)"),
-              I18N_NOOP("Cover (back)"),
-              I18N_NOOP("Leaflet page"),
-              I18N_NOOP("Media"),
-              I18N_NOOP("Lead artist/lead performer/soloist"),
-              I18N_NOOP("Artist/performer"),
-              I18N_NOOP("Conductor"),
-              I18N_NOOP("Band/Orchestra"),
-              I18N_NOOP("Composer"),
-              I18N_NOOP("Lyricist/text writer"),
-              I18N_NOOP("Recording Location"),
-              I18N_NOOP("During recording"),
-              I18N_NOOP("During performance"),
-              I18N_NOOP("Movie/video screen capture"),
-              I18N_NOOP("A bright coloured fish"),
-              I18N_NOOP("Illustration"),
-              I18N_NOOP("Band/artist logotype"),
-              I18N_NOOP("Publisher/Studio logotype"),
-              NULL
-            };
-            IntComboBoxControl* cbox =
-              new IntComboBoxControl(fld, strlst);
-            if (cbox) {
-              m_fieldcontrols.append(cbox);
-            }
-          }
-          else if (fld.m_id == Frame::Field::ID_TimestampFormat) {
-            static const char* strlst[] = {
-              I18N_NOOP("Other"),
-              I18N_NOOP("MPEG frames as unit"),
-              I18N_NOOP("Milliseconds as unit"),
-              NULL
-            };
-            IntComboBoxControl* cbox =
-              new IntComboBoxControl(fld, strlst);
-            if (cbox) {
-              m_fieldcontrols.append(cbox);
-            }
-          }
-          else if (fld.m_id == Frame::Field::ID_ContentType) {
-            static const char* strlst[] = {
-              I18N_NOOP("Other"),
-              I18N_NOOP("Lyrics"),
-              I18N_NOOP("Text transcription"),
-              I18N_NOOP("Movement/part name"),
-              I18N_NOOP("Events"),
-              I18N_NOOP("Chord"),
-              I18N_NOOP("Trivia/pop up"),
-              NULL
-            };
-            IntComboBoxControl* cbox =
-              new IntComboBoxControl(fld, strlst);
-            if (cbox) {
-              m_fieldcontrols.append(cbox);
-            }
-          }
-          else {
-            IntFieldControl* intctl =
-              new IntFieldControl(fld);
-            if (intctl) {
-              m_fieldcontrols.append(intctl);
-            }
-          }
-          break;
-
-        case QVariant::String:
-          if (fld.m_id == Frame::Field::ID_Text) {
-            // Large textedit for text fields
-            TextFieldControl* textctl =
-              new TextFieldControl(fld);
-            if (textctl) {
-              m_fieldcontrols.append(textctl);
-            }
-          }
-          else {
-            LineFieldControl* textctl =
-              new LineFieldControl(fld);
-            if (textctl) {
-              m_fieldcontrols.append(textctl);
-            }
-          }
-          break;
-
-        case QVariant::ByteArray:
-        {
-          BinFieldControl* binctl =
-            new BinFieldControl(fld, frame, taggedFile);
-          if (binctl) {
-            m_fieldcontrols.append(binctl);
-          }
-          break;
+  for (Frame::FieldList::iterator fldIt = m_fields.begin();
+       fldIt != m_fields.end();
+       ++fldIt) {
+    Frame::Field& fld = *fldIt;
+    switch (fld.m_value.type()) {
+      case QVariant::Int:
+      case QVariant::UInt:
+        if (fld.m_id == Frame::Field::ID_TextEnc) {
+          static const char* strlst[] = {
+            I18N_NOOP("ISO-8859-1"),
+            I18N_NOOP("UTF16"),
+            I18N_NOOP("UTF16BE"),
+            I18N_NOOP("UTF8"),
+            NULL
+          };
+          IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
+          m_fieldcontrols.append(cbox);
         }
+        else if (fld.m_id == Frame::Field::ID_PictureType) {
+          static const char* strlst[] = {
+            I18N_NOOP("Other"),
+            I18N_NOOP("32x32 pixels PNG file icon"),
+            I18N_NOOP("Other file icon"),
+            I18N_NOOP("Cover (front)"),
+            I18N_NOOP("Cover (back)"),
+            I18N_NOOP("Leaflet page"),
+            I18N_NOOP("Media"),
+            I18N_NOOP("Lead artist/lead performer/soloist"),
+            I18N_NOOP("Artist/performer"),
+            I18N_NOOP("Conductor"),
+            I18N_NOOP("Band/Orchestra"),
+            I18N_NOOP("Composer"),
+            I18N_NOOP("Lyricist/text writer"),
+            I18N_NOOP("Recording Location"),
+            I18N_NOOP("During recording"),
+            I18N_NOOP("During performance"),
+            I18N_NOOP("Movie/video screen capture"),
+            I18N_NOOP("A bright coloured fish"),
+            I18N_NOOP("Illustration"),
+            I18N_NOOP("Band/artist logotype"),
+            I18N_NOOP("Publisher/Studio logotype"),
+            NULL
+          };
+          IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
+          m_fieldcontrols.append(cbox);
+        }
+        else if (fld.m_id == Frame::Field::ID_TimestampFormat) {
+          static const char* strlst[] = {
+            I18N_NOOP("Other"),
+            I18N_NOOP("MPEG frames as unit"),
+            I18N_NOOP("Milliseconds as unit"),
+            NULL
+          };
+          IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
+          m_fieldcontrols.append(cbox);
+        }
+        else if (fld.m_id == Frame::Field::ID_ContentType) {
+          static const char* strlst[] = {
+            I18N_NOOP("Other"),
+            I18N_NOOP("Lyrics"),
+            I18N_NOOP("Text transcription"),
+            I18N_NOOP("Movement/part name"),
+            I18N_NOOP("Events"),
+            I18N_NOOP("Chord"),
+            I18N_NOOP("Trivia/pop up"),
+            NULL
+          };
+          IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
+          m_fieldcontrols.append(cbox);
+        }
+        else {
+          IntFieldControl* intctl = new IntFieldControl(fld);
+          m_fieldcontrols.append(intctl);
+        }
+        break;
 
-        default:
-          qDebug("Unknown type %d in field %d", fld.m_value.type(), fld.m_id);
+      case QVariant::String:
+        if (fld.m_id == Frame::Field::ID_Text) {
+          // Large textedit for text fields
+          TextFieldControl* textctl = new TextFieldControl(fld);
+          m_fieldcontrols.append(textctl);
+        }
+        else {
+          LineFieldControl* textctl = new LineFieldControl(fld);
+          m_fieldcontrols.append(textctl);
+        }
+        break;
+
+      case QVariant::ByteArray:
+      {
+        BinFieldControl* binctl = new BinFieldControl(fld, frame, taggedFile);
+        m_fieldcontrols.append(binctl);
+        break;
       }
-    }
 
-    QListIterator<FieldControl*> it(m_fieldcontrols);
-    while (it.hasNext()) {
-      vlayout->addWidget(it.next()->createWidget(this));
+      default:
+        qDebug("Unknown type %d in field %d", fld.m_value.type(), fld.m_id);
     }
   }
+
+  QListIterator<FieldControl*> it(m_fieldcontrols);
+  while (it.hasNext()) {
+    vlayout->addWidget(it.next()->createWidget(this));
+  }
+
   QHBoxLayout* hlayout = new QHBoxLayout;
   QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
              QSizePolicy::Minimum);
   QPushButton* okButton = new QPushButton(i18n("&OK"), this);
   QPushButton* cancelButton = new QPushButton(i18n("&Cancel"), this);
-  if (hlayout && okButton && cancelButton) {
-    hlayout->addItem(hspacer);
-    hlayout->addWidget(okButton);
-    hlayout->addWidget(cancelButton);
-    okButton->setDefault(true);
-    connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
-    connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
-    vlayout->addLayout(hlayout);
-  }
+  hlayout->addItem(hspacer);
+  hlayout->addWidget(okButton);
+  hlayout->addWidget(cancelButton);
+  okButton->setDefault(true);
+  connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
+  connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
+  vlayout->addLayout(hlayout);
   setMinimumWidth(525);
 }
 
