@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -63,7 +63,7 @@
 #include "trackdatamatcher.h"
 #include "qtcompatmac.h"
 #include "config.h"
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
 #include "musicbrainzdialog.h"
 #include "musicbrainzconfig.h"
 #endif
@@ -90,13 +90,16 @@ QList<int> checkableFrameTypes() {
  * @param trackDataModel track data to be filled with imported values,
  *                      is passed with durations of files set
  * @param importers     server importers
+ * @param mbClient      MusicBrainz client if supported, else 0
  */
 ImportDialog::ImportDialog(QWidget* parent, QString& caption,
                            TrackDataModel* trackDataModel,
-                           const QList<ServerImporter*>& importers) :
+                           const QList<ServerImporter*>& importers,
+                           MusicBrainzClient* mbClient) :
   QDialog(parent),
   m_autoStartSubDialog(-1), m_columnVisibility(0ULL),
-  m_trackDataModel(trackDataModel), m_importers(importers)
+  m_trackDataModel(trackDataModel), m_importers(importers),
+  m_musicBrainzClient(mbClient)
 {
   setObjectName("ImportDialog");
   setModal(true);
@@ -106,7 +109,7 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   m_serverImportDialog = 0;
   m_textImportDialog = 0;
   m_tagImportDialog = 0;
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
   m_musicBrainzDialog = 0;
 #endif
 
@@ -151,7 +154,7 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   foreach (const ServerImporter* si, m_importers) {
     m_serverComboBox->addItem(QCM_translate(si->name()));
   }
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
   m_serverComboBox->addItem(i18n("MusicBrainz Fingerprint"));
 #endif
   butlayout->addWidget(m_serverComboBox);
@@ -173,7 +176,7 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
 #ifdef CONFIG_USE_KDE
         KIcon("document-revert")
 #else
-        QIcon(":/images/document-revert.png")
+        QCM_QIcon_fromTheme("document-revert")
 #endif
         );
   revertButton->setToolTip(i18n("Revert"));
@@ -250,7 +253,7 @@ ImportDialog::~ImportDialog()
   delete m_textImportDialog;
   delete m_tagImportDialog;
   delete m_serverImportDialog;
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
   delete m_musicBrainzDialog;
 #endif
 }
@@ -305,7 +308,7 @@ void ImportDialog::displayServerImportDialog(int importerIdx)
       displayServerImportDialog(m_importers.at(importerIdx));
     } else {
       // special case for MusicBrainz Fingerprint
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
       fromMusicBrainz();
 #endif
     }
@@ -324,13 +327,11 @@ void ImportDialog::displayServerImportDialog(ServerImporter* source)
     connect(m_serverImportDialog, SIGNAL(trackDataUpdated()),
             this, SLOT(showPreview()));
   }
-  if (m_serverImportDialog) {
-    m_serverImportDialog->setImportSource(source);
-    m_serverImportDialog->setArtistAlbum(
-          m_trackDataModel->trackData().getArtist(),
-          m_trackDataModel->trackData().getAlbum());
-    m_serverImportDialog->show();
-  }
+  m_serverImportDialog->setImportSource(source);
+  m_serverImportDialog->setArtistAlbum(
+        m_trackDataModel->trackData().getArtist(),
+        m_trackDataModel->trackData().getAlbum());
+  m_serverImportDialog->show();
 }
 
 /**
@@ -346,21 +347,20 @@ void ImportDialog::hideSubdialogs()
     m_tagImportDialog->hide();
 }
 
-#ifdef HAVE_TUNEPIMP
+#ifdef HAVE_CHROMAPRINT
 /**
  * Import from MusicBrainz and preview in table.
  */
 void ImportDialog::fromMusicBrainz()
 {
   if (!m_musicBrainzDialog) {
-    m_musicBrainzDialog = new MusicBrainzDialog(this, m_trackDataModel);
+    m_musicBrainzDialog = new MusicBrainzDialog(this, m_trackDataModel,
+                                                m_musicBrainzClient);
     connect(m_musicBrainzDialog, SIGNAL(trackDataUpdated()),
             this, SLOT(showPreview()));
   }
-  if (m_musicBrainzDialog) {
-    m_musicBrainzDialog->initTable();
-    (void)m_musicBrainzDialog->exec();
-  }
+  m_musicBrainzDialog->initTable();
+  (void)m_musicBrainzDialog->exec();
 }
 #endif
 
