@@ -164,11 +164,10 @@ void TextImportDialog::fromFile()
 #ifdef CONFIG_USE_KDE
     KFileDialog::getOpenFileName(ConfigStore::s_genCfg.m_importDir, QString::null, this)
 #else
-    QFileDialog::getOpenFileName(this, QString(), ConfigStore::s_genCfg.m_importDir
-#if !defined Q_OS_WIN32 && !defined Q_OS_MAC
-      , QString(), 0, QFileDialog::DontUseNativeDialog
-#endif
-      )
+    QFileDialog::getOpenFileName(this, QString(),
+      ConfigStore::s_genCfg.m_importDir, QString(), 0,
+      ConfigStore::s_miscCfg.m_dontUseNativeDialogs
+      ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0))
 #endif
     );
 }
