@@ -45,6 +45,7 @@
 #include <QUrl>
 #include <QApplication>
 #include <QFileSystemModel>
+#include <QMimeData>
 #include "frametable.h"
 #include "frametablemodel.h"
 #include "trackdata.h"
@@ -61,6 +62,11 @@
 #include "kid3application.h"
 #include "qtcompatmac.h"
 
+#ifndef CONFIG_USE_KDE
+#include <QAction>
+#include "shortcutsmodel.h"
+#endif
+
 /** Collapse pixmap, will be allocated in constructor */
 QPixmap* Kid3Form::s_collapsePixmap = 0;
 /** Expand pixmap, will be allocated in constructor */
@@ -879,3 +885,48 @@ void Kid3Form::setDirectoryIndex(const QModelIndex& directoryIndex,
   m_fileListBox->readDir(directoryIndex, fileIndex);
   m_dirListBox->readDir(directoryIndex);
 }
+
+#ifndef CONFIG_USE_KDE
+/**
+ * Init actions.
+ */
+void Kid3Form::initActions()
+{
+  QString ctx(i18n("Filename"));
+  ShortcutsModel* sm = m_app->getConfigStore()->getShortcutsModel();
+  initAction(i18n("From Tag 1"), "filename_from_v1", this, SLOT(fnFromID3V1()), ctx, sm);
+  initAction(i18n("From Tag 2"), "filename_from_v2", this, SLOT(fnFromID3V2()), ctx, sm);
+  initAction(i18n("Focus"), "filename_focus", this, SLOT(setFocusFilename()), ctx, sm);
+  ctx = i18n("Tag 1");
+  initAction(i18n("From Filename"), "v1_from_filename", m_app, SLOT(getTagsFromFilenameV1()), ctx, sm);
+  initAction(i18n("From Tag 2"), "v1_from_v2", m_app, SLOT(copyV2ToV1()), ctx, sm);
+  initAction(i18n("Copy"), "v1_copy", m_app, SLOT(copyTagsV1()), ctx, sm);
+  initAction(i18n("Paste"), "v1_paste", m_app, SLOT(pasteTagsV1()), ctx, sm);
+  initAction(i18n("Remove"), "v1_remove", m_app, SLOT(removeTagsV1()), ctx, sm);
+  initAction(i18n("Focus"), "v1_focus", this, SLOT(setFocusV1()), ctx, sm);
+  ctx = i18n("Tag 2");
+  initAction(i18n("From Filename"), "v2_from_filename", m_app, SLOT(getTagsFromFilenameV2()), ctx, sm);
+  initAction(i18n("From Tag 1"), "v2_from_v1", m_app, SLOT(copyV1ToV2()), ctx, sm);
+  initAction(i18n("Copy"), "v2_copy", m_app, SLOT(copyTagsV2()), ctx, sm);
+  initAction(i18n("Paste"), "v2_paste", m_app, SLOT(pasteTagsV2()), ctx, sm);
+  initAction(i18n("Remove"), "v2_remove", m_app, SLOT(removeTagsV2()), ctx, sm);
+  initAction(i18n("Edit"), "frames_edit", this, SLOT(editFrame()), ctx, sm);
+  initAction(i18n("Add"), "frames_add", this, SLOT(addFrame()), ctx, sm);
+  initAction(i18n("Delete"), "frames_delete", this, SLOT(deleteFrame()), ctx, sm);
+  initAction(i18n("Focus"), "v2_focus", this, SLOT(setFocusV2()), ctx, sm);
+}
+
+void Kid3Form::initAction(const QString& text, const QString& name,
+                          const QObject* receiver, const char* slot,
+                          const QString& context,
+                          ShortcutsModel* shortcutsModel)
+{
+  QAction* action = new QAction(this);
+  action->setStatusTip(text);
+  action->setText(text);
+  action->setObjectName(name);
+  shortcutsModel->registerAction(action, context);
+  connect(action, SIGNAL(triggered()), receiver, slot);
+  addAction(action);
+}
+#endif // CONFIG_USE_KDE
