@@ -30,6 +30,7 @@
 #include <QSplitter>
 #include <QLineEdit>
 #include "taggedfile.h"
+#include "config.h"
 
 class QLabel;
 class QCheckBox;
@@ -48,6 +49,7 @@ class FileList;
 class DirList;
 class PictureLabel;
 class Kid3MainWindow;
+class ShortcutsModel;
 
 /**
  * Main widget.
@@ -194,6 +196,13 @@ public:
    */
   FrameTable* frameTableV2() { return m_framesV2Table; }
 
+#ifndef CONFIG_USE_KDE
+  /**
+   * Init actions.
+   */
+  void initActions();
+#endif
+
 public slots:
   /**
    * Frame list button Edit.
@@ -284,6 +293,12 @@ private:
    */
   Kid3MainWindow* mainWin() const { return (Kid3MainWindow*)parentWidget(); }
 
+#ifndef CONFIG_USE_KDE
+  void initAction(const QString& text, const QString& name,
+                  const QObject* receiver, const char* slot,
+                  const QString& context, ShortcutsModel* shortcutsModel);
+#endif
+
   FileList* m_fileListBox;
   QComboBox* m_formatComboBox;
   QComboBox* m_formatFromFilenameComboBox;
